;+
; NAME:
;     SXT_RPAXY
; PURPOSE:
;     calculate radii, position angles, and xy's for SXT
; CATEGORY:
;     Yohkoh
; CALLING SEQUENCE:
;     sxt_rpaxy, index, rr, pa, xy
;     sxt_rpaxy, index, rr, pa, xy, center=center
;     sxt_rpaxy, index, /get
;     sxt_rpaxy, index, /get, coords=coords
; INPUTS:
;     index of an image
; OPTIONAL (KEYWORD) INPUT PARAMETERS:
;     center, allows input of a coordinate center (default fov center)
;     show, shows rpaxy results
;     pix, gives rr output in pixel units (otherwise R_sun units)
;     get, prints clicked coordinates to screen (presupposes you've
;      displayed the image already)
;    coords, contains clicked position as described if /get
; OUTPUTS:
;     rr, map of radius values relative to SXT_CEN sun center, 
;       in units of solar radii 
;     pa, map of position angles (positive E from N, degrees)
;     xy(dim, dim, 2) maps of x and y values relative to sun center
; COMMON BLOCKS:
; SIDE EFFECTS:
; RESTRICTIONS:
; MODIFICATION HISTORY:
;     HSH, written 20-jun-97
;     29-sep-00, added "center" and "show" keywords (HSH)
;      9-sep-01, added "get"  and "coords" keywords
;-
pro sxt_rpaxy, index, rr, pa, xy, qstop = qstop, center=center, $
  show=show, pix=pix, get=get, coords=coords
rad = 180/!pi
res = 2^gt_res(index)
dim = 1024/res
cen = sxt_cen(index)/res
if n_elements(center) ne 0 then begin
  siz = size(center)
  if siz(0) eq 1 then begin
    cen = center
  endif else begin
    cen = gt_shape_cmd(index)/2
  endelse
  dim = (gt_shape_cmd(index))(0) 
endif
rr = fltarr(dim,dim)
pa = fltarr(dim,dim)
xy = fltarr(dim,dim,2)
radius = get_rb0p(index,/rad)/gt_pix_size(index)
x = findgen(dim)
for i = 0, dim-1 do begin
  xy(*,i,0) = x - cen(0)
  xy(i,*,1) = x - cen(1)
endfor
rr = sqrt(xy(*,*,0)^2+xy(*,*,1)^2) / radius
pa = atan(-xy(*,*,0),xy(*,*,1))*rad
neg = where(pa lt 0)
pa(neg) = pa(neg) + 360
if keyword_set(show) then begin
  tvscl,rr
  tvscl,pa,dim,0
  tvscl,xy(*,*,0),2*dim,0
  tvscl,xy(*,*,1),3*dim,0
endif
if keyword_set(get) then begin
  print,' '
  print,'Click on target'
  cursor,x,y,/dev
  print,"Position angle  ", pa(x,y)
  print,"Radial distance ", rr(x,y)
  Print,"SOHO-style X    ", xy(x,y,0)*gt_pix_size(index)
  Print,"SOHO-style Y    ", xy(x,y,1)*gt_pix_size(index)
  print,' '
  coords = [pa(x,y),rr(x,y),xy(x,y,0)*gt_pix_size(index),$
    xy(x,y,1)*gt_pix_size(index)]
endif
if keyword_set(pix) then rr = rr * radius 
if keyword_set(qstop) then stop
end

